==> windmill_api-1.46.2.tar.gz: windmill_api-1.46.2/windmill_api/models/path_script_input_transforms_additional_property_type_1.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.path_script_input_transforms_additional_property_type_1_type import (
    PathScriptInputTransformsAdditionalPropertyType1Type,
)

T = TypeVar("T", bound="PathScriptInputTransformsAdditionalPropertyType1")


@attr.s(auto_attribs=True)
class PathScriptInputTransformsAdditionalPropertyType1:
    """
    Attributes:
        expr (str):
        type (PathScriptInputTransformsAdditionalPropertyType1Type):
    """

    expr: str
    type: PathScriptInputTransformsAdditionalPropertyType1Type
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        expr = self.expr
        type = self.type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "expr": expr,
                "type": type,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        expr = d.pop("expr")

        type = PathScriptInputTransformsAdditionalPropertyType1Type(d.pop("type"))

        path_script_input_transforms_additional_property_type_1 = cls(
            expr=expr,
            type=type,
        )

        path_script_input_transforms_additional_property_type_1.additional_properties = d
        return path_script_input_transforms_additional_property_type_1

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> windmill_api-1.246.10.tar.gz: windmill_api-1.246.10/windmill_api/models/path_script_input_transforms_additional_property_type_1.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.path_script_input_transforms_additional_property_type_1_type import (
    PathScriptInputTransformsAdditionalPropertyType1Type,
)

T = TypeVar("T", bound="PathScriptInputTransformsAdditionalPropertyType1")


@_attrs_define
class PathScriptInputTransformsAdditionalPropertyType1:
    """
    Attributes:
        expr (str):
        type (PathScriptInputTransformsAdditionalPropertyType1Type):
    """

    expr: str
    type: PathScriptInputTransformsAdditionalPropertyType1Type
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        expr = self.expr
        type = self.type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "expr": expr,
                "type": type,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        expr = d.pop("expr")

        type = PathScriptInputTransformsAdditionalPropertyType1Type(d.pop("type"))

        path_script_input_transforms_additional_property_type_1 = cls(
            expr=expr,
            type=type,
        )

        path_script_input_transforms_additional_property_type_1.additional_properties = d
        return path_script_input_transforms_additional_property_type_1

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
